@@ -8,9 +8,11 @@ from dagster.core.definitions import (
     ExecutorDefinition,
     ExpectationResult,
     Failure,
+    FirstPartitionSelector,
     InputDefinition,
     InputMapping,
     JsonMetadataEntryData,
+    LastPartitionSelector,
     LoggerDefinition,
     MarkdownMetadataEntryData,
     Materialization,
@@ -19,6 +21,8 @@ from dagster.core.definitions import (
     Output,
     OutputDefinition,
     OutputMapping,
+    Partition,
+    PartitionSetDefinition,
     PathMetadataEntryData,
     PipelineDefinition,
     PresetDefinition,
@@ -40,6 +44,7 @@ from dagster.core.definitions import (
     logger,
     multiprocess_executor,
     pipeline,
+    repository_partitions,
     resource,
     schedules,
     solid,
