@@ -36,7 +36,7 @@ from .stack import EvaluationStack, get_friendly_path_msg
 from .traversal_context import TraversalContext
 
 
-def evaluate_config(config_type, config_value, pipeline=None, run_config=None, seen_handles=None):
+def evaluate_config(config_type, config_value, pipeline=None, run_config=None):
     return _evaluate_config(
         TraversalContext(
             config_type=check.inst_param(config_type, 'config_type', ConfigType),
@@ -46,7 +46,7 @@ def evaluate_config(config_type, config_value, pipeline=None, run_config=None, s
             run_config=check.opt_inst_param(
                 run_config, 'run_config', IRunConfig, default=RunConfig()
             ),
-            seen_handles=check.opt_list_param(seen_handles, 'seen_handles'),
+            seen_handles=[],
         )
     )
 
@@ -310,7 +310,7 @@ def _evaluate_composite_solid_config(context):
         )
 
     # When evaluating nested composite solids defined with config mapping functions but empty config
-    if 'solids' in context.config_value:
+    if 'solids' in mapped_config_value:
         mapped_config_value = context.config_value.get('solids')
 
     # We've validated the composite solid config; now validate the mapping fn overrides against the
